"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: a244d5f2afc5

from __future__ import annotations
from .classifiertrainingparameters import (
    ClassifierTrainingParameters,
    ClassifierTrainingParametersTypedDict,
)
from .jobmetadata import JobMetadata, JobMetadataTypedDict
from .wandbintegrationresult import (
    WandbIntegrationResult,
    WandbIntegrationResultTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import ConfigDict, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


ClassifierFineTuningJobStatus = Union[
    Literal[
        "QUEUED",
        "STARTED",
        "VALIDATING",
        "VALIDATED",
        "RUNNING",
        "FAILED_VALIDATION",
        "FAILED",
        "SUCCESS",
        "CANCELLED",
        "CANCELLATION_REQUESTED",
    ],
    UnrecognizedStr,
]
r"""The current status of the fine-tuning job."""


ClassifierFineTuningJobIntegrationTypedDict = WandbIntegrationResultTypedDict


class UnknownClassifierFineTuningJobIntegration(BaseModel):
    r"""A ClassifierFineTuningJobIntegration variant the SDK doesn't recognize. Preserves the raw payload."""

    type: Literal["UNKNOWN"] = "UNKNOWN"
    raw: Any
    is_unknown: Literal[True] = True

    model_config = ConfigDict(frozen=True)


_CLASSIFIER_FINE_TUNING_JOB_INTEGRATION_VARIANTS: dict[str, Any] = {
    "wandb": WandbIntegrationResult,
}


ClassifierFineTuningJobIntegration = WandbIntegrationResult


class ClassifierFineTuningJobTypedDict(TypedDict):
    id: str
    r"""The ID of the job."""
    auto_start: bool
    model: str
    status: ClassifierFineTuningJobStatus
    r"""The current status of the fine-tuning job."""
    created_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was created."""
    modified_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was last modified."""
    training_files: List[str]
    r"""A list containing the IDs of uploaded files that contain training data."""
    hyperparameters: ClassifierTrainingParametersTypedDict
    validation_files: NotRequired[Nullable[List[str]]]
    r"""A list containing the IDs of uploaded files that contain validation data."""
    object: Literal["job"]
    r"""The object type of the fine-tuning job."""
    fine_tuned_model: NotRequired[Nullable[str]]
    r"""The name of the fine-tuned model that is being created. The value will be `null` if the fine-tuning job is still running."""
    suffix: NotRequired[Nullable[str]]
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""
    integrations: NotRequired[
        Nullable[List[ClassifierFineTuningJobIntegrationTypedDict]]
    ]
    r"""A list of integrations enabled for your fine-tuning job."""
    trained_tokens: NotRequired[Nullable[int]]
    r"""Total number of tokens trained."""
    metadata: NotRequired[Nullable[JobMetadataTypedDict]]
    job_type: Literal["classifier"]
    r"""The type of job (`FT` for fine-tuning)."""


class ClassifierFineTuningJob(BaseModel):
    id: str
    r"""The ID of the job."""

    auto_start: bool

    model: str

    status: ClassifierFineTuningJobStatus
    r"""The current status of the fine-tuning job."""

    created_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was created."""

    modified_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was last modified."""

    training_files: List[str]
    r"""A list containing the IDs of uploaded files that contain training data."""

    hyperparameters: ClassifierTrainingParameters

    validation_files: OptionalNullable[List[str]] = UNSET
    r"""A list containing the IDs of uploaded files that contain validation data."""

    object: Annotated[
        Annotated[Optional[Literal["job"]], AfterValidator(validate_const("job"))],
        pydantic.Field(alias="object"),
    ] = "job"
    r"""The object type of the fine-tuning job."""

    fine_tuned_model: OptionalNullable[str] = UNSET
    r"""The name of the fine-tuned model that is being created. The value will be `null` if the fine-tuning job is still running."""

    suffix: OptionalNullable[str] = UNSET
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""

    integrations: OptionalNullable[List[ClassifierFineTuningJobIntegration]] = UNSET
    r"""A list of integrations enabled for your fine-tuning job."""

    trained_tokens: OptionalNullable[int] = UNSET
    r"""Total number of tokens trained."""

    metadata: OptionalNullable[JobMetadata] = UNSET

    job_type: Annotated[
        Annotated[Literal["classifier"], AfterValidator(validate_const("classifier"))],
        pydantic.Field(alias="job_type"),
    ] = "classifier"
    r"""The type of job (`FT` for fine-tuning)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "validation_files",
                "object",
                "fine_tuned_model",
                "suffix",
                "integrations",
                "trained_tokens",
                "metadata",
            ]
        )
        nullable_fields = set(
            [
                "validation_files",
                "fine_tuned_model",
                "suffix",
                "integrations",
                "trained_tokens",
                "metadata",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    ClassifierFineTuningJob.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8957175b7482

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeleteModelResponseTypedDict(TypedDict):
    id: str
    r"""The ID of the deleted model."""
    object: NotRequired[str]
    r"""The object type that was deleted"""
    deleted: NotRequired[bool]
    r"""The deletion status"""


class DeleteModelResponse(BaseModel):
    id: str
    r"""The ID of the deleted model."""

    object: Optional[str] = "model"
    r"""The object type that was deleted"""

    deleted: Optional[bool] = True
    r"""The deletion status"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object", "deleted"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7948899b3068

from __future__ import annotations
from .connectorcalltoolrequest import (
    ConnectorCallToolRequest,
    ConnectorCallToolRequestTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorCallToolV1RequestTypedDict(TypedDict):
    tool_name: str
    connector_id_or_name: str
    connector_call_tool_request: ConnectorCallToolRequestTypedDict
    credentials_name: NotRequired[Nullable[str]]


class ConnectorCallToolV1Request(BaseModel):
    tool_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_id_or_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_call_tool_request: Annotated[
        ConnectorCallToolRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    credentials_name: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["credentials_name"])
        nullable_fields = set(["credentials_name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



from typing import Mapping, Optional

from pydantic import BaseModel

from mistralai.client import errors, models, utils
from mistralai.client._hooks.types import HookContext
from mistralai.client.sdk import Mistral
from mistralai.client.types.basemodel import UNSET, OptionalNullable
from mistralai.client.utils.security import get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response


class WorkerInfo(BaseModel):
    scheduler_url: str
    namespace: str


async def get_scheduler_namespace(
    client: Mistral,
    *,
    retries: OptionalNullable[utils.RetryConfig] = UNSET,
    server_url: Optional[str] = None,
    timeout_ms: Optional[int] = None,
    http_headers: Optional[Mapping[str, str]] = None,
) -> str:
    base_url = None
    url_variables = None
    if timeout_ms is None:
        timeout_ms = client.sdk_configuration.timeout_ms

    if server_url is not None:
        base_url = server_url
    else:
        base_url = client._get_url(base_url, url_variables)
    req = client._build_request_async(
        method="GET",
        path="/v1/workflows/workers/whoami",
        base_url=base_url,
        url_variables=url_variables,
        request=None,
        request_body_required=False,
        request_has_path_params=False,
        request_has_query_params=True,
        user_agent_header="user-agent",
        accept_header_value="application/json",
        http_headers=http_headers,
        security=client.sdk_configuration.security,
        allow_empty_value=None,
        timeout_ms=timeout_ms,
    )

    if retries == UNSET:
        if client.sdk_configuration.retry_config is not UNSET:
            retries = client.sdk_configuration.retry_config

    retry_config = None
    if isinstance(retries, utils.RetryConfig):
        retry_config = (retries, ["429", "500", "502", "503", "504"])

    http_res = await client.do_request_async(
        hook_ctx=HookContext(
            config=client.sdk_configuration,
            base_url=base_url or "",
            operation_id="get_worker_info_v1_workflows_workers_whoami_get",
            oauth2_scopes=None,
            security_source=get_security_from_env(
                client.sdk_configuration.security, models.Security
            ),
        ),
        request=req,
        error_status_codes=["4XX", "5XX"],
        retry_config=retry_config,
    )

    if utils.match_response(http_res, "200", "application/json"):
        return unmarshal_json_response(WorkerInfo, http_res).namespace
    if utils.match_response(http_res, "4XX", "*"):
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError("API error occurred", http_res, http_res_text)
    if utils.match_response(http_res, "5XX", "*"):
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.SDKError("API error occurred", http_res, http_res_text)

    raise errors.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 48b4f6f50fe9

from __future__ import annotations
from .function import Function, FunctionTypedDict
from mistralai.client.types import BaseModel, UnrecognizedStr
from mistralai.client.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


class ToolTypedDict(TypedDict):
    function: FunctionTypedDict
    type: Union[Literal["function"], UnrecognizedStr]


class Tool(BaseModel):
    function: Function

    type: Annotated[
        Annotated[
            Union[Literal["function"], UnrecognizedStr],
            AfterValidator(validate_const("function")),
        ],
        pydantic.Field(alias="type"),
    ] = "function"


try:
    Tool.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7033fdb33ad4

from __future__ import annotations
from .audioformat import AudioFormat, AudioFormatTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class RealtimeTranscriptionSessionUpdatePayloadTypedDict(TypedDict):
    audio_format: NotRequired[Nullable[AudioFormatTypedDict]]
    r"""Set before sending audio. Audio format updates are rejected after audio starts."""
    target_streaming_delay_ms: NotRequired[Nullable[int]]
    r"""Set before sending audio. Streaming delay updates are rejected after audio starts."""


class RealtimeTranscriptionSessionUpdatePayload(BaseModel):
    audio_format: OptionalNullable[AudioFormat] = UNSET
    r"""Set before sending audio. Audio format updates are rejected after audio starts."""

    target_streaming_delay_ms: OptionalNullable[int] = UNSET
    r"""Set before sending audio. Streaming delay updates are rejected after audio starts."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["audio_format", "target_streaming_delay_ms"])
        nullable_fields = set(["audio_format", "target_streaming_delay_ms"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f9d442a062b5

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScheduleRangeTypedDict(TypedDict):
    start: int
    end: NotRequired[int]
    step: NotRequired[int]


class ScheduleRange(BaseModel):
    start: int

    end: Optional[int] = 0

    step: Optional[int] = 0

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["end", "step"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: c61d451066dc

from __future__ import annotations
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class JudgeRegressionOutputTypedDict(TypedDict):
    min_description: str
    max_description: str
    type: Literal["REGRESSION"]
    min: NotRequired[float]
    max: NotRequired[float]


class JudgeRegressionOutput(BaseModel):
    min_description: str

    max_description: str

    type: Annotated[
        Annotated[Literal["REGRESSION"], AfterValidator(validate_const("REGRESSION"))],
        pydantic.Field(alias="type"),
    ] = "REGRESSION"

    min: Optional[float] = 0

    max: Optional[float] = 1

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["min", "max"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    JudgeRegressionOutput.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5ec0889995f5

from __future__ import annotations
from .connectorsqueryfilters import (
    ConnectorsQueryFilters,
    ConnectorsQueryFiltersTypedDict,
)
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorListV1RequestTypedDict(TypedDict):
    query_filters: NotRequired[ConnectorsQueryFiltersTypedDict]
    cursor: NotRequired[Nullable[str]]
    page_size: NotRequired[int]


class ConnectorListV1Request(BaseModel):
    query_filters: Annotated[
        Optional[ConnectorsQueryFilters],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    cursor: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["query_filters", "cursor", "page_size"])
        nullable_fields = set(["cursor"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



import random
from typing import Dict, Union

import httpx
from opentelemetry.propagate import inject

from .types import BeforeRequestContext, BeforeRequestHook


_EXECUTE_OPERATION_IDS = {
    "execute_workflow_v1_workflows__workflow_identifier__execute_post",
    "execute_workflow_registration_v1_workflows_registrations__workflow_registration_id__execute_post",
}


class TraceparentInjectionHook(BeforeRequestHook):
    """Inject a sampled traceparent on /execute requests so worker traces are always recorded."""

    def before_request(
        self, hook_ctx: BeforeRequestContext, request: httpx.Request
    ) -> Union[httpx.Request, Exception]:
        if hook_ctx.operation_id not in _EXECUTE_OPERATION_IDS:
            return request

        # Don't overwrite an explicitly provided traceparent.
        if "traceparent" in request.headers:
            return request

        carrier: Dict[str, str] = {}
        inject(carrier)
        traceparent = carrier.get("traceparent", "")
        if not traceparent.endswith("-01"):
            trace_id = random.getrandbits(128)
            span_id = random.getrandbits(64)
            traceparent = f"00-{trace_id:032x}-{span_id:016x}-01"

        request.headers["traceparent"] = traceparent
        return request



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 50a25e4e336c

from __future__ import annotations
from .mirrorconfig import MirrorConfig, MirrorConfigTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import ConfigDict, model_serializer
from typing import Any, Dict, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


InternalMetadataAgentVersionTypedDict = TypeAliasType(
    "InternalMetadataAgentVersionTypedDict", Union[str, int]
)


InternalMetadataAgentVersion = TypeAliasType(
    "InternalMetadataAgentVersion", Union[str, int]
)


class InternalMetadataTypedDict(TypedDict):
    r"""Typed structure for internal metadata."""

    agent_id: NotRequired[Nullable[str]]
    agent_version: NotRequired[Nullable[InternalMetadataAgentVersionTypedDict]]
    mirror_config: NotRequired[Nullable[MirrorConfigTypedDict]]
    science_config: NotRequired[Nullable[Dict[str, Any]]]


class InternalMetadata(BaseModel):
    r"""Typed structure for internal metadata."""

    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    agent_id: OptionalNullable[str] = UNSET

    agent_version: OptionalNullable[InternalMetadataAgentVersion] = UNSET

    mirror_config: OptionalNullable[MirrorConfig] = UNSET

    science_config: OptionalNullable[Dict[str, Any]] = UNSET

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["agent_id", "agent_version", "mirror_config", "science_config"]
        )
        nullable_fields = set(
            ["agent_id", "agent_version", "mirror_config", "science_config"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            serialized.pop(k, serialized.pop(n, None))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val
        for k, v in serialized.items():
            m[k] = v

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: d3b4fe452390

from .basesdk import BaseSDK
from mistralai.client import errors, models, utils
from mistralai.client._hooks import HookContext
from mistralai.client.types import OptionalNullable, UNSET
from mistralai.client.utils import get_security_from_env
from mistralai.client.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional, Union


class Schedules(BaseSDK):
    def get_schedules(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WorkflowScheduleListResponse:
        r"""Get Schedules

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/v1/workflows/schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_schedules_v1_workflows_schedules_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WorkflowScheduleListResponse, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def get_schedules_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WorkflowScheduleListResponse:
        r"""Get Schedules

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/v1/workflows/schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_schedules_v1_workflows_schedules_get",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WorkflowScheduleListResponse, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def schedule_workflow(
        self,
        *,
        schedule: Union[models.ScheduleDefinition, models.ScheduleDefinitionTypedDict],
        workflow_registration_id: OptionalNullable[str] = UNSET,
        workflow_version_id: OptionalNullable[str] = UNSET,
        workflow_identifier: OptionalNullable[str] = UNSET,
        workflow_task_queue: OptionalNullable[str] = UNSET,
        schedule_id: OptionalNullable[str] = UNSET,
        deployment_name: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WorkflowScheduleResponse:
        r"""Schedule Workflow

        :param schedule: Specification of the times scheduled actions may occur.

            The times are the union of :py:attr:`calendars`, :py:attr:`intervals`, and
            :py:attr:`cron_expressions` excluding anything in :py:attr:`skip`.

            Used for input where schedule_id is optional (can be provided or auto-generated).
        :param workflow_registration_id: The ID of the workflow registration to schedule
        :param workflow_version_id: Deprecated: use workflow_registration_id
        :param workflow_identifier: The name or ID of the workflow to schedule
        :param workflow_task_queue: Deprecated. Use deployment_name instead.
        :param schedule_id: Allows you to specify a custom schedule ID. If not provided, a random ID will be generated.
        :param deployment_name: Name of the deployment to route this schedule to
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WorkflowScheduleRequest(
            schedule=utils.get_pydantic_model(schedule, models.ScheduleDefinition),
            workflow_registration_id=workflow_registration_id,
            workflow_version_id=workflow_version_id,
            workflow_identifier=workflow_identifier,
            workflow_task_queue=workflow_task_queue,
            schedule_id=schedule_id,
            deployment_name=deployment_name,
        )

        req = self._build_request(
            method="POST",
            path="/v1/workflows/schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.WorkflowScheduleRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="schedule_workflow_v1_workflows_schedules_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.WorkflowScheduleResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def schedule_workflow_async(
        self,
        *,
        schedule: Union[models.ScheduleDefinition, models.ScheduleDefinitionTypedDict],
        workflow_registration_id: OptionalNullable[str] = UNSET,
        workflow_version_id: OptionalNullable[str] = UNSET,
        workflow_identifier: OptionalNullable[str] = UNSET,
        workflow_task_queue: OptionalNullable[str] = UNSET,
        schedule_id: OptionalNullable[str] = UNSET,
        deployment_name: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WorkflowScheduleResponse:
        r"""Schedule Workflow

        :param schedule: Specification of the times scheduled actions may occur.

            The times are the union of :py:attr:`calendars`, :py:attr:`intervals`, and
            :py:attr:`cron_expressions` excluding anything in :py:attr:`skip`.

            Used for input where schedule_id is optional (can be provided or auto-generated).
        :param workflow_registration_id: The ID of the workflow registration to schedule
        :param workflow_version_id: Deprecated: use workflow_registration_id
        :param workflow_identifier: The name or ID of the workflow to schedule
        :param workflow_task_queue: Deprecated. Use deployment_name instead.
        :param schedule_id: Allows you to specify a custom schedule ID. If not provided, a random ID will be generated.
        :param deployment_name: Name of the deployment to route this schedule to
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WorkflowScheduleRequest(
            schedule=utils.get_pydantic_model(schedule, models.ScheduleDefinition),
            workflow_registration_id=workflow_registration_id,
            workflow_version_id=workflow_version_id,
            workflow_identifier=workflow_identifier,
            workflow_task_queue=workflow_task_queue,
            schedule_id=schedule_id,
            deployment_name=deployment_name,
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/workflows/schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.WorkflowScheduleRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="schedule_workflow_v1_workflows_schedules_post",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.WorkflowScheduleResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    def unschedule_workflow(
        self,
        *,
        schedule_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ):
        r"""Unschedule Workflow

        :param schedule_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UnscheduleWorkflowV1WorkflowsSchedulesScheduleIDDeleteRequest(
            schedule_id=schedule_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1/workflows/schedules/{schedule_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="unschedule_workflow_v1_workflows_schedules__schedule_id__delete",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)

    async def unschedule_workflow_async(
        self,
        *,
        schedule_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ):
        r"""Unschedule Workflow

        :param schedule_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if timeout_ms is None:
            timeout_ms = 30000

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UnscheduleWorkflowV1WorkflowsSchedulesScheduleIDDeleteRequest(
            schedule_id=schedule_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1/workflows/schedules/{schedule_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="unschedule_workflow_v1_workflows_schedules__schedule_id__delete",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKError("API error occurred", http_res, http_res_text)

        raise errors.SDKError("Unexpected response received", http_res)



import re
import unittest
from unittest.mock import MagicMock

import httpx
from opentelemetry.sdk.trace import TracerProvider
from opentelemetry.sdk.trace.export import SimpleSpanProcessor
from opentelemetry.sdk.trace.export.in_memory_span_exporter import InMemorySpanExporter
from opentelemetry.sdk.trace.sampling import ALWAYS_OFF

from mistralai.client._hooks.traceparent import TraceparentInjectionHook
from mistralai.client._hooks.types import BeforeRequestContext, HookContext


TRACEPARENT_RE = re.compile(r"^00-[0-9a-f]{32}-[0-9a-f]{16}-01$")

_EXECUTE_OP_ID = "execute_workflow_v1_workflows__workflow_identifier__execute_post"
_EXECUTE_REG_OP_ID = "execute_workflow_registration_v1_workflows_registrations__workflow_registration_id__execute_post"
_OTHER_OP_ID = "list_executions_v1_workflows__workflow_identifier__executions_get"


def _make_hook_ctx(operation_id: str = _EXECUTE_OP_ID) -> BeforeRequestContext:
    ctx = HookContext(
        config=MagicMock(),
        base_url="https://api.mistral.ai",
        operation_id=operation_id,
        oauth2_scopes=None,
        security_source=None,
    )
    return BeforeRequestContext(ctx)


def _make_request(path: str, traceparent: str | None = None) -> httpx.Request:
    headers = {}
    if traceparent is not None:
        headers["traceparent"] = traceparent
    return httpx.Request("POST", f"https://api.mistral.ai{path}", headers=headers)


class TestTraceparentInjectionHook(unittest.TestCase):
    def setUp(self):
        self.hook = TraceparentInjectionHook()

    # --- non-execute operations must NOT be touched ---

    def test_other_operation_is_unchanged(self):
        req = _make_request("/v1/workflows/my-wf/executions")
        result = self.hook.before_request(_make_hook_ctx(_OTHER_OP_ID), req)
        assert isinstance(result, httpx.Request)
        self.assertNotIn("traceparent", result.headers)

    # --- execute operations: header injected ---

    def test_execute_gets_sampled_traceparent(self):
        req = _make_request("/v1/workflows/my-wf/execute")
        result = self.hook.before_request(_make_hook_ctx(_EXECUTE_OP_ID), req)
        assert isinstance(result, httpx.Request)
        self.assertIn("traceparent", result.headers)
        self.assertRegex(result.headers["traceparent"], TRACEPARENT_RE)

    def test_execute_registration_gets_sampled_traceparent(self):
        req = _make_request("/v1/workflows/registrations/reg-id/execute")
        result = self.hook.before_request(_make_hook_ctx(_EXECUTE_REG_OP_ID), req)
        assert isinstance(result, httpx.Request)
        self.assertIn("traceparent", result.headers)
        self.assertRegex(result.headers["traceparent"], TRACEPARENT_RE)

    def test_explicit_traceparent_is_not_overwritten(self):
        explicit = "00-aabbccddeeff00112233445566778899-0102030405060708-01"
        req = _make_request("/v1/workflows/my-wf/execute", traceparent=explicit)
        result = self.hook.before_request(_make_hook_ctx(_EXECUTE_OP_ID), req)
        assert isinstance(result, httpx.Request)
        self.assertEqual(result.headers["traceparent"], explicit)

    # --- OTEL context propagation ---

    def test_propagates_sampled_active_span(self):
        exporter = InMemorySpanExporter()
        provider = TracerProvider()
        provider.add_span_processor(SimpleSpanProcessor(exporter))
        tracer = provider.get_tracer("test")

        with tracer.start_as_current_span("parent") as span:
            req = _make_request("/v1/workflows/my-wf/execute")
            result = self.hook.before_request(_make_hook_ctx(_EXECUTE_OP_ID), req)

        assert isinstance(result, httpx.Request)
        injected = result.headers["traceparent"]
        self.assertTrue(injected.endswith("-01"))
        trace_id_hex = f"{span.get_span_context().trace_id:032x}"
        self.assertIn(trace_id_hex, injected)

    def test_generates_fresh_traceparent_when_no_active_span(self):
        req = _make_request("/v1/workflows/my-wf/execute")
        result = self.hook.before_request(_make_hook_ctx(_EXECUTE_OP_ID), req)
        assert isinstance(result, httpx.Request)
        self.assertRegex(result.headers["traceparent"], TRACEPARENT_RE)

    def test_generates_fresh_traceparent_when_span_is_unsampled(self):
        provider = TracerProvider(sampler=ALWAYS_OFF)
        tracer = provider.get_tracer("test")

        with tracer.start_as_current_span("unsampled-parent"):
            req = _make_request("/v1/workflows/my-wf/execute")
            result = self.hook.before_request(_make_hook_ctx(_EXECUTE_OP_ID), req)

        assert isinstance(result, httpx.Request)
        injected = result.headers["traceparent"]
        self.assertTrue(injected.endswith("-01"), f"Expected sampled, got: {injected}")

if __name__ == "__main__":
    unittest.main()



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 0ae165cc7a82

from __future__ import annotations
from .workflow import Workflow, WorkflowTypedDict
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class WorkflowUpdateResponseTypedDict(TypedDict):
    workflow: WorkflowTypedDict


class WorkflowUpdateResponse(BaseModel):
    workflow: Workflow



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 793a9301522f

from __future__ import annotations
from .eventsource import EventSource
from .streameventssepayload import StreamEventSsePayload, StreamEventSsePayloadTypedDict
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class StreamV1WorkflowsExecutionsExecutionIDStreamGetRequestTypedDict(TypedDict):
    execution_id: str
    event_source: NotRequired[Nullable[EventSource]]
    last_event_id: NotRequired[Nullable[str]]


class StreamV1WorkflowsExecutionsExecutionIDStreamGetRequest(BaseModel):
    execution_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    event_source: Annotated[
        OptionalNullable[EventSource],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    last_event_id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event_source", "last_event_id"])
        nullable_fields = set(["event_source", "last_event_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class StreamV1WorkflowsExecutionsExecutionIDStreamGetResponseBodyTypedDict(TypedDict):
    r"""Stream of Server-Sent Events (SSE)"""

    event: NotRequired[str]
    data: NotRequired[StreamEventSsePayloadTypedDict]
    id: NotRequired[str]
    retry: NotRequired[int]


class StreamV1WorkflowsExecutionsExecutionIDStreamGetResponseBody(BaseModel):
    r"""Stream of Server-Sent Events (SSE)"""

    event: Optional[str] = None

    data: Optional[StreamEventSsePayload] = None

    id: Optional[str] = None

    retry: Optional[int] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["event", "data", "id", "retry"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
